@@ -15,7 +15,7 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @version    $Id $
  */
@@ -27,7 +27,7 @@ require_once 'Zend/Db/Statement/TestCommon.php';
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Db
  * @group      Zend_Db_Statement
@@ -41,7 +41,7 @@ abstract class Zend_Db_Statement_Pdo_TestCommon extends Zend_Db_Statement_TestCo
             ->from('zfproducts');
         $sql = $select->__toString();
         $stmt = new Zend_Db_Statement_Pdo($this->_db, $sql);
-        $this->assertType('Zend_Db_Statement_Pdo', $stmt);
+        $this->assertTrue($stmt instanceof Zend_Db_Statement_Pdo);
         $stmt->closeCursor();
     }
 
@@ -50,7 +50,7 @@ abstract class Zend_Db_Statement_Pdo_TestCommon extends Zend_Db_Statement_TestCo
         $select = $this->_db->select()
             ->from('zfproducts');
         $stmt = new Zend_Db_Statement_Pdo($this->_db, $select);
-        $this->assertType('Zend_Db_Statement_Interface', $stmt);
+        $this->assertTrue($stmt instanceof Zend_Db_Statement_Interface);
         $stmt->closeCursor();
     }
 
@@ -63,7 +63,7 @@ abstract class Zend_Db_Statement_Pdo_TestCommon extends Zend_Db_Statement_TestCo
             $stmt->nextRowset();
             $this->fail('Expected to catch Zend_Db_Statement_Exception');
         } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Db_Statement_Exception', $e,
+            $this->assertTrue($e instanceof Zend_Db_Statement_Exception,
                 'Expecting object of type Zend_Db_Statement_Exception, got '.get_class($e));
             $this->assertEquals('SQLSTATE[IM001]: Driver does not support this function: driver does not support multiple rowsets', $e->getMessage());
         }
@@ -81,7 +81,7 @@ abstract class Zend_Db_Statement_Pdo_TestCommon extends Zend_Db_Statement_TestCo
         foreach ($stmt as $test) {
             $this->assertTrue($test instanceof stdClass);
         }
-        $this->assertType('int', iterator_count($stmt));
+        $this->assertTrue(is_int(iterator_count($stmt)));
     }
 
     public function testStatementConstructExceptionBadSql()
@@ -91,10 +91,10 @@ abstract class Zend_Db_Statement_Pdo_TestCommon extends Zend_Db_Statement_TestCo
             $stmt = $this->_db->query($sql);
             $this->fail('Expected to catch Zend_Db_Statement_Exception');
         } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Db_Statement_Exception', $e,
+            $this->assertTrue($e instanceof Zend_Db_Statement_Exception,
                 'Expecting object of type Zend_Db_Statement_Exception, got '.get_class($e));
             $this->assertTrue($e->hasChainedException(), 'Missing Chained Exception');
-            $this->assertType('PDOException', $e->getChainedException(), 'Wrong type of Exception');
+            $this->assertTrue($e->getChainedException() instanceof PDOException, 'Wrong type of Exception');
         }
     }
 
