@@ -15,16 +15,28 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id$
  */
 
 require_once 'Zend/Db/TestSetup.php';
 
 require_once 'Zend/Db/Statement/Exception.php';
 
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
 
+
+
+
+/**
+ * @category   Zend
+ * @package    Zend_Db
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Db
+ * @group      Zend_Db_Statement
+ */
 abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
 {
 
@@ -36,7 +48,8 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
             ->from('zfproducts');
         $sql = $select->__toString();
         $stmt = new $statementClass($this->_db, $sql);
-        $this->assertType('Zend_Db_Statement_Interface', $stmt);
+        $this->assertTrue($stmt instanceof Zend_Db_Statement_Interface);
+        $this->assertTrue($stmt instanceof Zend_Db_Statement_Interface);
         $stmt->closeCursor();
     }
 
@@ -47,7 +60,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
         $select = $this->_db->select()
             ->from('zfproducts');
         $stmt = new $statementClass($this->_db, $select);
-        $this->assertType('Zend_Db_Statement_Interface', $stmt);
+        $this->assertTrue($stmt instanceof Zend_Db_Statement_Interface);
         $stmt->closeCursor();
     }
 
@@ -56,7 +69,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
         $select = $this->_db->select()
             ->from('zfproducts');
         $stmt = $this->_db->prepare($select->__toString());
-        $this->assertType('Zend_Db_Statement_Interface', $stmt);
+        $this->assertTrue($stmt instanceof Zend_Db_Statement_Interface);
         $stmt->closeCursor();
     }
 
@@ -65,7 +78,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
         $select = $this->_db->select()
             ->from('zfproducts');
         $stmt = $this->_db->query($select);
-        $this->assertType('Zend_Db_Statement_Interface', $stmt);
+        $this->assertTrue($stmt instanceof Zend_Db_Statement_Interface);
         $stmt->closeCursor();
     }
 
@@ -74,7 +87,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
         $stmt = $this->_db->select()
             ->from('zfproducts')
             ->query();
-        $this->assertType('Zend_Db_Statement_Interface', $stmt);
+        $this->assertTrue($stmt instanceof Zend_Db_Statement_Interface);
         $stmt->closeCursor();
     }
 
@@ -85,7 +98,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
             $stmt = $this->_db->query($sql);
             $this->fail('Expected to catch Zend_Db_Statement_Exception');
         } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Db_Statement_Exception', $e,
+            $this->assertTrue($e instanceof Zend_Db_Statement_Exception,
                 'Expecting object of type Zend_Db_Statement_Exception, got '.get_class($e));
         }
     }
@@ -98,7 +111,8 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
         $stmt = $this->_db->prepare("DELETE FROM $products WHERE $product_id = 1");
 
         $n = $stmt->rowCount();
-        $this->assertType('integer', $n);
+        $this->assertTrue(is_int($n));
+        $this->assertTrue(is_int($n));
         $this->assertEquals(0, $n, 'Expecting row count to be 0 before executing query');
 
         $stmt->execute();
@@ -106,7 +120,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
         $n = $stmt->rowCount();
         $stmt->closeCursor();
 
-        $this->assertType('integer', $n);
+        $this->assertTrue(is_int($n));
         $this->assertEquals(1, $n, 'Expected row count to be one after executing query');
     }
 
@@ -125,7 +139,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
         $n = $stmt->columnCount();
         $stmt->closeCursor();
 
-        $this->assertType('integer', $n);
+        $this->assertTrue(is_int($n));
         $this->assertEquals(2, $n);
     }
 
@@ -178,11 +192,11 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
             }
             $this->fail('Expected to catch Zend_Db_Statement_Exception');
         } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Db_Statement_Exception', $e,
+            $this->assertTrue($e instanceof Zend_Db_Statement_Exception,
                 'Expecting object of type Zend_Db_Statement_Exception, got '.get_class($e));
         }
         $code = $stmt->errorCode();
-        // @todo: what to assert here?
+        // @todo  what to assert here?
     }
 
     public function testStatementErrorInfoKeyViolation()
@@ -200,13 +214,13 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
             }
             $this->fail('Expected to catch Zend_Db_Statement_Exception');
         } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Db_Statement_Exception', $e,
+            $this->assertTrue($e instanceof Zend_Db_Statement_Exception,
                 'Expecting object of type Zend_Db_Statement_Exception, got '.get_class($e));
         }
         $code = $stmt->errorCode();
         $info = $stmt->errorInfo();
         $this->assertEquals($code, $info[0]);
-        // @todo: what to assert here?
+        // @todo  what to assert here?
     }
 
     public function testStatementSetFetchModeAssoc()
@@ -294,7 +308,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
         $result = $stmt->fetchAll();
 
         $this->assertEquals(2, count($result));
-        $this->assertType('stdClass', $result[0]);
+        $this->assertTrue($result[0] instanceof stdClass);
 
         // check for FETCH_OBJ entries
         $this->assertEquals(2, $result[0]->product_id);
@@ -312,9 +326,9 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
             $stmt->setFetchMode(-999);
             $this->fail('Expected to catch Zend_Db_Statement_Exception');
         } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Db_Statement_Exception', $e,
+            $this->assertTrue($e instanceof Zend_Db_Statement_Exception,
                 'Expecting object of type Zend_Db_Statement_Exception, got '.get_class($e));
-            $this->assertContains('invalid fetch mode', $e->getMessage());
+            $this->assertRegExp('#invalid fetch mode#i', $e->getMessage());
         }
     }
 
@@ -386,7 +400,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
         $result = $stmt->fetchAll(Zend_Db::FETCH_OBJ);
 
         $this->assertEquals(2, count($result));
-        $this->assertType('stdClass', $result[0]);
+        $this->assertTrue($result[0] instanceof stdClass);
         $this->assertEquals(2, $result[0]->product_id);
     }
 
@@ -412,7 +426,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
         $result = $stmt->fetchAll(Zend_Db::FETCH_COLUMN, 1);
 
         $this->assertEquals(2, count($result));
-        $this->assertType('string', $result[0]);
+        $this->assertTrue(is_string($result[0]));
         $this->assertEquals('Linux', $result[0]);
         $this->assertEquals('OS X', $result[1]);
     }
@@ -427,7 +441,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
             $result = $stmt->fetchAll(-99);
             $this->fail('Expected to catch Zend_Db_Statement_Exception');
         } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Db_Statement_Exception', $e,
+            $this->assertTrue($e instanceof Zend_Db_Statement_Exception,
                 'Expecting object of type Zend_Db_Statement_Exception, got '.get_class($e));
         }
         $stmt->closeCursor();
@@ -486,7 +500,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
         $result = $stmt->fetchObject();
         $stmt->closeCursor();
 
-        $this->assertType('stdClass', $result,
+        $this->assertTrue($result instanceof stdClass,
             'Expecting object of type stdClass, got '.get_class($result));
         $this->assertEquals('Linux', $result->product_name);
     }
@@ -513,7 +527,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
         $result = $stmt->fetch(Zend_Db::FETCH_NUM);
         $stmt->closeCursor();
 
-        $this->assertType('array', $result);
+        $this->assertTrue(is_array($result));
         $this->assertEquals('Linux', $result[1]);
         $this->assertFalse(isset($result['product_name']));
     }
@@ -527,7 +541,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
         $result = $stmt->fetch(Zend_Db::FETCH_ASSOC);
         $stmt->closeCursor();
 
-        $this->assertType('array', $result);
+        $this->assertTrue(is_array($result));
         $this->assertEquals('Linux', $result['product_name']);
         $this->assertFalse(isset($result[1]));
     }
@@ -541,7 +555,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
         $result = $stmt->fetch(Zend_Db::FETCH_BOTH);
         $stmt->closeCursor();
 
-        $this->assertType('array', $result);
+        $this->assertTrue(is_array($result));
         $this->assertEquals('Linux', $result[1]);
         $this->assertEquals('Linux', $result['product_name']);
     }
@@ -555,7 +569,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
         $result = $stmt->fetch(Zend_Db::FETCH_OBJ);
         $stmt->closeCursor();
 
-        $this->assertType('stdClass', $result,
+        $this->assertTrue($result instanceof stdClass,
             'Expecting object of type stdClass, got '.get_class($result));
         $this->assertEquals('Linux', $result->product_name);
     }
@@ -570,7 +584,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
             $result = $stmt->fetch(-99);
             $this->fail('Expected to catch Zend_Db_Statement_Exception');
         } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Db_Statement_Exception', $e,
+            $this->assertTrue($e instanceof Zend_Db_Statement_Exception,
                 'Expecting object of type Zend_Db_Statement_Exception, got '.get_class($e));
         }
         $stmt->closeCursor();
@@ -791,7 +805,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
         $stmt->execute();
         for ($i = 0; $i < $stmt->columnCount(); ++$i) {
             $meta = $stmt->getColumnMeta($i);
-            $this->assertType('array', $meta);
+            $this->assertTrue(is_array($meta));
             foreach ($this->_getColumnMetaKeys as $key) {
                 if ($key == 'table' && version_compare(PHP_VERSION, '5.2.0', '<')) {
                     continue;
@@ -810,7 +824,7 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
             $stmt->nextRowset();
             $this->fail('Expected to catch Zend_Db_Statement_Exception');
         } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Db_Statement_Exception', $e,
+            $this->assertTrue($e instanceof Zend_Db_Statement_Exception,
                 'Expecting object of type Zend_Db_Statement_Exception, got '.get_class($e));
             $this->assertEquals('nextRowset() is not implemented', $e->getMessage());
         }
@@ -849,4 +863,14 @@ abstract class Zend_Db_Statement_TestCommon extends Zend_Db_TestSetup
         $this->assertEquals($value, $stmt->getAttribute(1234), "Expected '$value' #2");
     }
 
+    /**
+     * @group ZF-7706
+     */
+    public function testStatementCanReturnDriverStatement()
+    {
+        $products = $this->_db->quoteIdentifier('zfproducts');
+        $statement = $this->_db->query("SELECT * FROM $products");
+        $this->assertNotNull($statement->getDriverStatement());
+        return $statement;
+    }
 }
