@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,30 +15,23 @@
  * @category   Zend
  * @package    Zend_Feed
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ArrayAccessTest.php 8064 2008-02-16 10:58:39Z thomas $
+ * @version    $Id$
  */
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
-
 /**
  * @see Zend_Feed
  */
 require_once 'Zend/Feed.php';
 
-
 /**
  * @category   Zend
  * @package    Zend_Feed
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Feed
  */
 class Zend_Feed_ArrayAccessTest extends PHPUnit_Framework_TestCase
 {
@@ -96,4 +88,14 @@ class Zend_Feed_ArrayAccessTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('', $nsfeed['version'], 'Version should be equal to the empty string');
     }
 
+    /**
+     * @group ZF-5354
+     */
+    public function testGetsLinkWithEmptyOrMissingRelAsAlternateRel()
+    {
+        $feed = Zend_Feed::importFile(dirname(__FILE__) . '/_files/AtomHOnline.xml');
+        $entry = $feed->current();
+        $this->assertEquals('http://www.h-online.com/security/Google-acquires-reCAPTCHA--/news/114266/from/rss', $entry->link('alternate'));
+    }
+
 }
