@@ -13,24 +13,29 @@
  * to license@zend.com so we can send you a copy immediately.
  *
  * @category   Zend
- * @package    Zend_Gdata
+ * @package    Zend_Gdata_Calendar
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2006 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id $
  */
 
 require_once 'Zend/Gdata/Calendar.php';
 require_once 'Zend/Gdata/Calendar/EventQuery.php';
 require_once 'Zend/Http/Client.php';
-require_once 'PHPUnit/Framework/TestCase.php';
 
 /**
- * @package Zend_Gdata
+ * @category   Zend
+ * @package    Zend_Gdata_Calendar
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Gdata
+ * @group      Zend_Gdata_Calendar
  */
 class Zend_Gdata_Calendar_EventQueryExceptionTest extends PHPUnit_Framework_TestCase
 {
-    
+
     const GOOGLE_DEVELOPER_CALENDAR = 'developer-calendar@google.com';
 
     public function setUp()
@@ -44,7 +49,7 @@ class Zend_Gdata_Calendar_EventQueryExceptionTest extends PHPUnit_Framework_Test
     public function testSingleEventsThrowsExceptionOnSetInvalidValue()
     {
         $this->query->resetParameters();
-        $singleEvents = 'puppy';        
+        $singleEvents = 'puppy';
         $this->query->setUser(self::GOOGLE_DEVELOPER_CALENDAR);
         $this->query->setSingleEvents($singleEvents);
     }
@@ -55,9 +60,9 @@ class Zend_Gdata_Calendar_EventQueryExceptionTest extends PHPUnit_Framework_Test
     public function testFutureEventsThrowsExceptionOnSetInvalidValue()
     {
         $this->query->resetParameters();
-        $futureEvents = 'puppy';        
+        $futureEvents = 'puppy';
         $this->query->setUser(self::GOOGLE_DEVELOPER_CALENDAR);
         $this->query->setFutureEvents($futureEvents);
     }
-    
+
 }
