@@ -15,7 +15,7 @@
  * @category   Zend
  * @package    Zend_Mail
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @version    $Id $
  */
@@ -56,7 +56,7 @@ require_once 'Zend/Config.php';
  * @category   Zend
  * @package    Zend_Mail
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Mail_Transport_Mock extends Zend_Mail_Transport_Abstract
@@ -88,7 +88,7 @@ class Zend_Mail_Transport_Mock extends Zend_Mail_Transport_Abstract
  * @category   Zend
  * @package    Zend_Mail
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Mail_Transport_Sendmail_Mock extends Zend_Mail_Transport_Sendmail
@@ -114,12 +114,13 @@ class Zend_Mail_Transport_Sendmail_Mock extends Zend_Mail_Transport_Sendmail
  * @category   Zend
  * @package    Zend_Mail
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Mail
  */
 class Zend_Mail_MailTest extends PHPUnit_Framework_TestCase
 {
+    protected $numAssertions;
 
     public function tearDown() {
         Zend_Mail::clearDefaultFrom();
@@ -162,7 +163,7 @@ class Zend_Mail_MailTest extends PHPUnit_Framework_TestCase
         $this->assertContains('From: test Mail User <testmail@example.com>', $mock->header);
         $this->assertContains('Subject: My Subject', $mock->header);
         $this->assertContains('To: recipient1@example.com', $mock->header);
-        $this->assertContains('Cc: Example no. 1 for cc <recipient1_cc@example.com>', $mock->header);
+        $this->assertContains('Cc: "Example no. 1 for cc" <recipient1_cc@example.com>', $mock->header);
     }
 
     /**
@@ -209,6 +210,7 @@ class Zend_Mail_MailTest extends PHPUnit_Framework_TestCase
         $mail->addTo('address_to1@example.com', 'name_to@example.com');
         $mail->addTo('address_to2@example.com', 'noinclude comma nor at mark');
         $mail->addTo('address_to3@example.com', 'include brackets []');
+        $mail->addTo('address_to4@example.com', 'include dot .');
         $mail->addCc('address_cc@example.com', 'include, name_cc');
 
         $mock = new Zend_Mail_Transport_Mock();
@@ -220,6 +222,7 @@ class Zend_Mail_MailTest extends PHPUnit_Framework_TestCase
         $this->assertContains('To: "name_to@example.com" <address_to1@example.com>', $mock->header);
         $this->assertContains('noinclude comma nor at mark <address_to2@example.com>', $mock->header);
         $this->assertContains('"include brackets []" <address_to3@example.com>', $mock->header);
+        $this->assertContains('"include dot ." <address_to4@example.com>', $mock->header);
         $this->assertContains('Cc: "include, name_cc" <address_cc@example.com>', $mock->header);
     }
 
