@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,26 +15,23 @@
  * @category   Zend
  * @package    Zend_Measure
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2006 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AreaTest.php 6799 2007-11-09 22:44:42Z thomas $
+ * @version    $Id$
  */
 
-
 /**
  * Zend_Measure_Area
  */
 require_once 'Zend/Measure/Area.php';
 
 /**
- * PHPUnit test case
- */
-require_once 'PHPUnit/Framework/TestCase.php';
-
-
-/**
+ * @category   Zend
  * @package    Zend_Measure
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Measure
  */
 class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
 {
@@ -49,7 +45,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($value instanceof Zend_Measure_Area,'Zend_Measure_Area Object not returned');
     }
 
-
     /**
      * test for exception unknown type
      * expected exception
@@ -64,7 +59,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         }
     }
 
-
     /**
      * test for exception unknown value
      * expected exception
@@ -79,7 +73,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         }
     }
 
-
     /**
      * test for exception unknown locale
      * expected root value
@@ -94,7 +87,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         }
     }
 
-
     /**
      * test for standard locale
      * expected integer
@@ -105,7 +97,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(100, $value->getValue(),'Zend_Measure_Area value expected');
     }
 
-
     /**
      * test for positive value
      * expected integer
@@ -116,7 +107,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(100, $value->getValue(), 'Zend_Measure_Area value expected to be a positive integer');
     }
 
-
     /**
      * test for negative value
      * expected integer
@@ -127,7 +117,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(-100, $value->getValue(), 'Zend_Measure_Area value expected to be a negative integer');
     }
 
-
     /**
      * test for decimal value
      * expected float
@@ -138,7 +127,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(-100.200, $value->getValue(), 'Zend_Measure_Area value expected to be a decimal value');
     }
 
-
     /**
      * test for decimal seperated value
      * expected float
@@ -149,42 +137,38 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(-100100.200, $value->getValue(),'Zend_Measure_Area Object not returned');
     }
 
-
     /**
      * test for string with integrated value
      * expected float
      */
     public function testAreaValueString()
     {
-        $value = new Zend_Measure_Area('string -100.100,200',Zend_Measure_Area::STANDARD,'de');
+        $value = new Zend_Measure_Area('-100.100,200',Zend_Measure_Area::STANDARD,'de');
         $this->assertEquals(-100100.200, $value->getValue(),'Zend_Measure_Area Object not returned');
     }
 
-
     /**
      * test for equality
      * expected true
      */
     public function testAreaEquality()
     {
-        $value = new Zend_Measure_Area('string -100.100,200',Zend_Measure_Area::STANDARD,'de');
-        $newvalue = new Zend_Measure_Area('otherstring -100.100,200',Zend_Measure_Area::STANDARD,'de');
+        $value = new Zend_Measure_Area('-100.100,200',Zend_Measure_Area::STANDARD,'de');
+        $newvalue = new Zend_Measure_Area('-100.100,200',Zend_Measure_Area::STANDARD,'de');
         $this->assertTrue($value->equals($newvalue),'Zend_Measure_Area Object should be equal');
     }
 
-
     /**
      * test for no equality
      * expected false
      */
     public function testAreaNoEquality()
     {
-        $value = new Zend_Measure_Area('string -100.100,200',Zend_Measure_Area::STANDARD,'de');
-        $newvalue = new Zend_Measure_Area('otherstring -100,200',Zend_Measure_Area::STANDARD,'de');
+        $value = new Zend_Measure_Area('-100.100,200',Zend_Measure_Area::STANDARD,'de');
+        $newvalue = new Zend_Measure_Area('-100,200',Zend_Measure_Area::STANDARD,'de');
         $this->assertFalse($value->equals($newvalue),'Zend_Measure_Area Object should be not equal');
     }
 
-
     /**
      * test for set positive value
      * expected integer
@@ -196,7 +180,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(200, $value->getValue(), 'Zend_Measure_Area value expected to be a positive integer');
     }
 
-
     /**
      * test for set negative value
      * expected integer
@@ -208,7 +191,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(-200, $value->getValue(), 'Zend_Measure_Area value expected to be a negative integer');
     }
 
-
     /**
      * test for set decimal value
      * expected float
@@ -220,7 +202,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(-200.200, $value->getValue(), 'Zend_Measure_Area value expected to be a decimal value');
     }
 
-
     /**
      * test for set decimal seperated value
      * expected float
@@ -232,19 +213,17 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(-200200.200, $value->getValue(),'Zend_Measure_Area Object not returned');
     }
 
-
     /**
      * test for set string with integrated value
      * expected float
      */
     public function testAreaSetString()
     {
-        $value = new Zend_Measure_Area('string -100.100,200',Zend_Measure_Area::STANDARD,'de');
-        $value->setValue('otherstring -200.200,200',Zend_Measure_Area::STANDARD,'de');
+        $value = new Zend_Measure_Area('-100.100,200',Zend_Measure_Area::STANDARD,'de');
+        $value->setValue('-200.200,200',Zend_Measure_Area::STANDARD,'de');
         $this->assertEquals(-200200.200, $value->getValue(),'Zend_Measure_Area Object not returned');
     }
 
-
     /**
      * test for exception unknown type
      * expected exception
@@ -253,14 +232,13 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
     {
         try {
             $value = new Zend_Measure_Area('100',Zend_Measure_Area::STANDARD,'de');
-            $value->setValue('otherstring -200.200,200','Area::UNKNOWN','de');
+            $value->setValue('-200.200,200','Area::UNKNOWN','de');
             $this->fail('Exception expected because of unknown type');
         } catch (Zend_Measure_Exception $e) {
             // success
         }
     }
 
-
     /**
      * test for exception unknown value
      * expected exception
@@ -276,7 +254,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         }
     }
 
-
     /**
      * test for exception unknown locale
      * expected exception
@@ -292,7 +269,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         }
     }
 
-
     /**
      * test for exception unknown locale
      * expected exception
@@ -304,7 +280,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(200, $value->getValue(), 'Zend_Measure_Area value expected to be a positive integer');
     }
 
-
     /**
      * test setting type
      * expected new type
@@ -316,7 +291,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(Zend_Measure_Area::MORGEN, $value->getType(), 'Zend_Measure_Area type expected');
     }
 
-
     /**
      * test setting computed type
      * expected new type
@@ -328,7 +302,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(Zend_Measure_Area::SQUARE_INCH, $value->getType(), 'Zend_Measure_Area type expected');
     }
 
-
     /**
      * test setting computed type
      * expected new type
@@ -340,7 +313,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(Zend_Measure_Area::SQUARE_MILE, $value->getType(), 'Zend_Measure_Area type expected');
     }
 
-
     /**
      * test setting unknown type
      * expected new type
@@ -356,7 +328,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         }
     }
 
-
     /**
      * test toString
      * expected string
@@ -367,7 +338,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('-100 m²', $value->toString(), 'Value -100 m² expected');
     }
 
-
     /**
      * test __toString
      * expected string
@@ -378,7 +348,6 @@ class Zend_Measure_AreaTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('-100 m²', $value->__toString(), 'Value -100 m² expected');
     }
 
-
     /**
      * test getConversionList
      * expected array
