@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,144 +15,53 @@
  * @category   Zend
  * @package    Zend_Validate
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AllTests.php 10656 2008-08-05 02:16:02Z matthew $
+ * @version    $Id$
  */
 
-
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Validate_AllTests::main');
 }
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
-/**
- * @see Zend_Validate_AbstractTest
- */
 require_once 'Zend/Validate/AbstractTest.php';
-
-/**
- * @see Zend_Validate_AlnumTest
- */
 require_once 'Zend/Validate/AlnumTest.php';
-
-/**
- * @see Zend_Validate_AlphaTest
- */
 require_once 'Zend/Validate/AlphaTest.php';
-
-/**
- * @see Zend_Validate_BarcodeTest
- */
 require_once 'Zend/Validate/BarcodeTest.php';
-
-/**
- * @see Zend_Validate_BetweenTest
- */
 require_once 'Zend/Validate/BetweenTest.php';
-
-/**
- * @see Zend_Validate_CcnumTest
- */
+require_once 'Zend/Validate/CallbackTest.php';
 require_once 'Zend/Validate/CcnumTest.php';
-
-/**
- * @see Zend_Validate_DateTest
- */
+require_once 'Zend/Validate/CreditCardTest.php';
 require_once 'Zend/Validate/DateTest.php';
-
-/**
- * @see Zend_Validate_DigitsTest
- */
+require_once 'Zend/Validate/Db/AllTests.php';
 require_once 'Zend/Validate/DigitsTest.php';
-
-/**
- * @see Zend_Validate_EmailAddressTest
- */
 require_once 'Zend/Validate/EmailAddressTest.php';
-
-/**
- * @see Zend_Validate_File_AllTests
- */
 require_once 'Zend/Validate/File/AllTests.php';
-
-/**
- * @see Zend_Validate_FloatTest
- */
 require_once 'Zend/Validate/FloatTest.php';
-
-/**
- * @see Zend_Validate_GreaterThanTest
- */
 require_once 'Zend/Validate/GreaterThanTest.php';
-
-/**
- * @see Zend_Validate_HexTest
- */
 require_once 'Zend/Validate/HexTest.php';
-
-/**
- * @see Zend_Validate_HostnameTest
- */
 require_once 'Zend/Validate/HostnameTest.php';
-
-/**
- * @see Zend_Validate_IdenticalTest
- */
+require_once 'Zend/Validate/IbanTest.php';
 require_once 'Zend/Validate/IdenticalTest.php';
-
-/**
- * @see Zend_Validate_InArrayTest
- */
 require_once 'Zend/Validate/InArrayTest.php';
-
-/**
- * @see Zend_Validate_IntTest
- */
 require_once 'Zend/Validate/IntTest.php';
-
-/**
- * @see Zend_Validate_IpTest
- */
 require_once 'Zend/Validate/IpTest.php';
-
-/**
- * @see Zend_Validate_LessThanTest
- */
+require_once 'Zend/Validate/IsbnTest.php';
 require_once 'Zend/Validate/LessThanTest.php';
-
-/**
- * @see Zend_Validate_MessageTest
- */
 require_once 'Zend/Validate/MessageTest.php';
-
-/**
- * @see Zend_Validate_NotEmptyTest
- */
 require_once 'Zend/Validate/NotEmptyTest.php';
-
-/**
- * @see Zend_Validate_RegexTest
- */
+require_once 'Zend/Validate/PostCodeTest.php';
 require_once 'Zend/Validate/RegexTest.php';
-
-/**
- * @see Zend_Validate_StringLengthTest
- */
+require_once 'Zend/Validate/Sitemap/AllTests.php';
 require_once 'Zend/Validate/StringLengthTest.php';
 
-
 /**
  * @category   Zend
  * @package    Zend_Validate
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Validate
  */
 class Zend_Validate_AllTests
 {
@@ -181,8 +89,11 @@ class Zend_Validate_AllTests
         $suite->addTestSuite('Zend_Validate_AlphaTest');
         $suite->addTestSuite('Zend_Validate_BarcodeTest');
         $suite->addTestSuite('Zend_Validate_BetweenTest');
+        $suite->addTestSuite('Zend_Validate_CallbackTest');
         $suite->addTestSuite('Zend_Validate_CcnumTest');
+        $suite->addTestSuite('Zend_Validate_CreditCardTest');
         $suite->addTestSuite('Zend_Validate_DateTest');
+        $suite->addTest(Zend_Validate_Db_AllTests::suite());
         $suite->addTestSuite('Zend_Validate_DigitsTest');
         $suite->addTestSuite('Zend_Validate_EmailAddressTest');
         $suite->addTest(Zend_Validate_File_AllTests::suite());
@@ -190,14 +101,18 @@ class Zend_Validate_AllTests
         $suite->addTestSuite('Zend_Validate_GreaterThanTest');
         $suite->addTestSuite('Zend_Validate_HexTest');
         $suite->addTestSuite('Zend_Validate_HostnameTest');
+        $suite->addTestSuite('Zend_Validate_IbanTest');
         $suite->addTestSuite('Zend_Validate_IdenticalTest');
         $suite->addTestSuite('Zend_Validate_InArrayTest');
         $suite->addTestSuite('Zend_Validate_IntTest');
         $suite->addTestSuite('Zend_Validate_IpTest');
+        $suite->addTestSuite('Zend_Validate_IsbnTest');
         $suite->addTestSuite('Zend_Validate_LessThanTest');
         $suite->addTestSuite('Zend_Validate_MessageTest');
         $suite->addTestSuite('Zend_Validate_NotEmptyTest');
+        $suite->addTestSuite('Zend_Validate_PostCodeTest');
         $suite->addTestSuite('Zend_Validate_RegexTest');
+        $suite->addTest(Zend_Validate_Sitemap_AllTests::suite());
         $suite->addTestSuite('Zend_Validate_StringLengthTest');
 
         return $suite;
