@@ -15,19 +15,15 @@
  * @category   Zend
  * @package    Zend_View
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_ViewTest::main');
 }
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../TestHelper.php';
-
 /**
  * Zend_View
  */
@@ -47,8 +43,9 @@ require_once 'Zend/Loader.php';
  * @category   Zend
  * @package    Zend_View
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_View
  */
 class Zend_ViewTest extends PHPUnit_Framework_TestCase
 {
@@ -79,11 +76,6 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $this->_testDefaultPath('script', false);
     }
 
-    public function normalizePath($path)
-    {
-        return str_replace(array('/', '\\'), DIRECTORY_SEPARATOR, $path);
-    }
-
     /**
      * Tests that the default helper path is properly initialized
      * and the directory is readable
@@ -141,10 +133,10 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $view = new Zend_View();
 
         $reflector = $view->getAllPaths();
-        $paths     = $reflector[$pathType];
+        $paths     = $this->_filterPath($reflector[$pathType]);
 
         // test default helper path
-        $this->assertType('array', $paths);
+        $this->assertTrue(is_array($paths));
         if ('script' == $pathType) {
             $this->assertEquals(0, count($paths));
         } else {
@@ -155,7 +147,12 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
 
             if ($testReadability) {
                 $path = current($paths[$prefix]);
-                $this->assertTrue(Zend_Loader::isReadable($path));
+
+                if (substr(PHP_OS, 0, 3) != 'WIN') {
+                    $this->assertTrue(Zend_Loader::isReadable($path));
+                } else {
+                    $this->assertTrue(is_dir($path));
+                }
             }
         }
     }
@@ -176,12 +173,12 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $expectedPaths = $reflector[$pathType];
 
         if ($pathType != 'script') {
-            $expectedPaths = $expectedPaths[$prefix];
+            $expectedPaths = $this->_filterPath($expectedPaths[$prefix]);
         }
 
-        array_push($expectedPaths, 'baz' . DIRECTORY_SEPARATOR);
-        array_push($expectedPaths, 'bar' . DIRECTORY_SEPARATOR);
-        array_push($expectedPaths, 'foo' . DIRECTORY_SEPARATOR);
+        array_push($expectedPaths, 'baz');
+        array_push($expectedPaths, 'bar');
+        array_push($expectedPaths, 'foo');
 
         // add paths
         $func = 'add' . ucfirst($pathType) . 'Path';
@@ -191,7 +188,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
 
         // introspect script paths after adding two new paths
         $reflector   = $view->getAllPaths();
-        $actualPaths = $reflector[$pathType];
+        $actualPaths = $this->_filterPath($reflector[$pathType]);
 
         switch ($pathType) {
             case 'script':
@@ -283,7 +280,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         try {
             // attempt to load the helper StubEmpty, whose file exists but
             // does not contain the expected class within
-            $view->stubEmpty();	
+            $view->stubEmpty();
             // @todo  fail if no exception?
         } catch (Zend_Exception $e) {
             $this->assertContains("not found", $e->getMessage());
@@ -395,7 +392,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         // add a path
         $view->setScriptPath('foo');
         $scriptPaths = $view->getScriptPaths();
-        $this->assertType('array', $scriptPaths);
+        $this->assertTrue(is_array($scriptPaths));
         $this->assertEquals(1, count($scriptPaths));
 
         // clear paths
@@ -449,14 +446,15 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
 
     /**
      * Test set/getEncoding()
+     * @group ZF-8715
      */
     public function testSetGetEncoding()
     {
         $view = new Zend_View();
-        $this->assertEquals('ISO-8859-1', $view->getEncoding());
-
-        $view->setEncoding('UTF-8');
         $this->assertEquals('UTF-8', $view->getEncoding());
+
+        $view->setEncoding('ISO-8859-1');
+        $this->assertEquals('ISO-8859-1', $view->getEncoding());
     }
 
     public function testEmptyPropertiesReturnAppropriately()
@@ -490,9 +488,9 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
 
     public function testSetConfigInConstructor()
     {
-        $scriptPath = $this->normalizePath(dirname(__FILE__) . '/View/_templates/');
-        $helperPath = $this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir1/');
-        $filterPath = $this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir1/');
+        $scriptPath = $this->_filterPath(dirname(__FILE__) . '/View/_templates/');
+        $helperPath = $this->_filterPath(dirname(__FILE__) . '/View/_stubs/HelperDir1/');
+        $filterPath = $this->_filterPath(dirname(__FILE__) . '/View/_stubs/HelperDir1/');
 
         $config = array(
             'escape'           => 'strip_tags',
@@ -510,23 +508,18 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $helperPaths = $view->getHelperPaths();
         $filterPaths = $view->getFilterPaths();
 
-        $this->assertContains($this->normalizePath($scriptPath), $scriptPaths);
+        $this->assertContains($this->_filterPath($scriptPath), $this->_filterPath($scriptPaths));
 
         $found  = false;
         $prefix = false;
         foreach ($helperPaths as $helperPrefix => $paths) {
             foreach ($paths as $path) {
+                $path = $this->_filterPath($path);
                 if (strstr($path, $helperPath)) {
                     $found  = true;
                     $prefix = $helperPrefix;
                 }
             }
-            /*
-            if (strstr($pathInfo['dir'], $helperPath)) {
-                $found  = true;
-                $prefix = $pathInfo['prefix'];
-            }
-             */
         }
         $this->assertTrue($found, var_export($helperPaths, 1));
         $this->assertEquals('My_View_Helper_', $prefix);
@@ -535,6 +528,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $prefix = false;
         foreach ($filterPaths as $classPrefix => $paths) {
             foreach ($paths as $pathInfo) {
+                $path = $this->_filterPath($pathInfo);
                 if (strstr($pathInfo, $filterPath)) {
                     $found  = true;
                     $prefix = $classPrefix;
@@ -571,14 +565,14 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $this->assertSame($view, $status);
         $helperPaths = $view->getHelperPaths();
         $this->assertTrue(array_key_exists('My_View_Helper_', $helperPaths));
-        $path = current($helperPaths['My_View_Helper_']);
-        $this->assertEquals($this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir1/'), $path);
+        $path = $this->_filterPath(current($helperPaths['My_View_Helper_']));
+        $this->assertEquals($this->_filterPath(dirname(__FILE__) . '/View/_stubs/HelperDir1/'), $path);
 
         $view->setHelperPath(dirname(__FILE__) . '/View/_stubs/HelperDir2/', 'Other_View_Helper');
         $helperPaths = $view->getHelperPaths();
         $this->assertTrue(array_key_exists('Other_View_Helper_', $helperPaths));
-        $path = current($helperPaths['Other_View_Helper_']);
-        $this->assertEquals($this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir2/'), $path);
+        $path = $this->_filterPath(current($helperPaths['Other_View_Helper_']));
+        $this->assertEquals($this->_filterPath(dirname(__FILE__) . '/View/_stubs/HelperDir2/'), $path);
     }
 
     public function testHelperPathWithPrefixAndRelativePath()
@@ -588,7 +582,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $this->assertSame($view, $status);
         $helperPaths = $view->getHelperPaths();
         $this->assertTrue(array_key_exists('My_View_Helper_', $helperPaths));
-        $this->assertContains($this->normalizePath('Zend/View/_stubs/HelperDir1/'), current($helperPaths['My_View_Helper_']));
+        $this->assertContains($this->_filterPath('Zend/View/_stubs/HelperDir1/'), $this->_filterPath(current($helperPaths['My_View_Helper_'])));
     }
 
     public function testFilterPathWithPrefix()
@@ -598,12 +592,12 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $this->assertSame($view, $status);
         $filterPaths = $view->getFilterPaths();
         $this->assertTrue(array_key_exists('My_View_Filter_', $filterPaths));
-        $this->assertEquals($this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir1/'), current($filterPaths['My_View_Filter_']));
+        $this->assertEquals($this->_filterPath(dirname(__FILE__) . '/View/_stubs/HelperDir1/'), $this->_filterPath(current($filterPaths['My_View_Filter_'])));
 
         $view->setFilterPath(dirname(__FILE__) . '/View/_stubs/HelperDir2/', 'Other_View_Filter');
         $filterPaths = $view->getFilterPaths();
         $this->assertTrue(array_key_exists('Other_View_Filter_', $filterPaths));
-        $this->assertEquals($this->normalizePath(dirname(__FILE__) . '/View/_stubs/HelperDir2/'), current($filterPaths['Other_View_Filter_']));
+        $this->assertEquals($this->_filterPath(dirname(__FILE__) . '/View/_stubs/HelperDir2/'), $this->_filterPath(current($filterPaths['Other_View_Filter_'])));
     }
 
     public function testAssignThrowsExceptionsOnBadValues()
@@ -653,6 +647,21 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $this->assertEquals("Some text", $escaped);
     }
 
+    /**
+     * @group ZF-9595
+     */
+    public function testEscapeShouldAllowAndUseMoreThanOneArgument()
+    {
+        $view = new Zend_View();
+        $view->setEscape(array($this, 'escape'));
+        $this->assertEquals('foobar', $view->escape('foo', 'bar'));
+    }
+
+    public function escape($value, $additional = '')
+    {
+        return $value . $additional;
+    }
+
     public function testZf995UndefinedPropertiesReturnNull()
     {
         error_reporting(E_ALL | E_STRICT);
@@ -672,7 +681,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('bar', $view->foo);
         $paths = $view->getScriptPaths();
         $this->assertEquals(1, count($paths));
-        $this->assertEquals(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'View' . DIRECTORY_SEPARATOR . '_templates' . DIRECTORY_SEPARATOR, $paths[0]);
+        $this->assertEquals(dirname(__FILE__) . '/View/_templates/', $paths[0]);
     }
 
     public function testHelperViewAccessor()
@@ -720,7 +729,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
 
     public function testSetBasePathFromConstructor()
     {
-        $base = dirname(__FILE__) . DIRECTORY_SEPARATOR . 'View';
+        $base = dirname(__FILE__) . '/View';
         $view = new Zend_View(array('basePath' => $base));
         $this->_testBasePath($view, $base);
     }
@@ -740,18 +749,35 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $this->_testBasePath($view, $base);
     }
 
+    protected function _filterPath($path)
+    {
+        if (is_array($path)) {
+            foreach ($path as $k => $p) {
+                $path[$k] = $this->_filterPath($p);
+            }
+            return $path;
+        }
+
+        $path = str_replace(DIRECTORY_SEPARATOR, '/', $path);
+        $path = str_replace('//', '/', $path);
+        $path = rtrim($path, '/');
+        return $path;
+    }
+
     protected function _testBasePath(Zend_View $view, $base, $classPrefix = null)
     {
-        $scriptPaths = $view->getScriptPaths();
-        $helperPaths = $view->getHelperPaths();
-        $filterPaths = $view->getFilterPaths();
-        $this->assertContains($base . DIRECTORY_SEPARATOR . 'scripts' . DIRECTORY_SEPARATOR, $scriptPaths);
+        $base        = $this->_filterPath($base);
+        $scriptPaths = $this->_filterPath($view->getScriptPaths());
+        $helperPaths = $this->_filterPath($view->getHelperPaths());
+        $filterPaths = $this->_filterPath($view->getFilterPaths());
+        $this->assertContains($base  . '/scripts', $scriptPaths);
 
         $found  = false;
         $prefix = false;
         foreach ($helperPaths as $pathPrefix => $paths) {
             foreach ($paths as $path) {
-                if ($path == $base . DIRECTORY_SEPARATOR . 'helpers' . DIRECTORY_SEPARATOR) {
+                $path = $this->_filterPath($path);
+                if ($path == $base . '/helpers') {
                     $found  = true;
                     $prefix = $pathPrefix;
                     break;
@@ -768,7 +794,8 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $prefix = false;
         foreach ($filterPaths as $pathPrefix => $paths) {
             foreach ($paths as $path) {
-                if ($path == $base . DIRECTORY_SEPARATOR . 'filters' . DIRECTORY_SEPARATOR) {
+                $path = $this->_filterPath($path);
+                if ($path == $base . '/filters') {
                     $found  = true;
                     $prefix = $pathPrefix;
                     break;
@@ -808,10 +835,10 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
     public function testGetScriptPath()
     {
         $view = new Zend_View();
-        $base = dirname(__FILE__) . DIRECTORY_SEPARATOR . 'View' . DIRECTORY_SEPARATOR . '_templates';
+        $base = dirname(__FILE__) . '/View/_templates';
         $view->setScriptPath($base);
         $path = $view->getScriptPath('test.phtml');
-        $this->assertEquals($base . DIRECTORY_SEPARATOR . 'test.phtml', $path);
+        $this->assertEquals($base . '/test.phtml', $path);
     }
 
     public function testGetHelper()
@@ -833,7 +860,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $view = new Zend_View();
         $view->declareVars();
         $helperPath = $view->getHelperPath('declareVars');
-        $this->assertContains($helperPath, $expected);
+        $this->assertContains($expected, $helperPath);
     }
 
     public function testGetFilter()
@@ -859,7 +886,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $view->addFilterPath($base . '_stubs' . DIRECTORY_SEPARATOR . 'FilterDir1');
 
         $filterPath = $view->getFilterPath('foo');
-        $this->assertEquals($expected, $filterPath);
+        $this->assertEquals($expected, $filterPath, var_export($filterPath, 1));
     }
 
     public function testGetFilters()
@@ -911,9 +938,9 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
 
         $this->assertSame($helper1, $helper2);
     }
-    
+
     /**
-     * @issue ZF-2742
+     * @group ZF-2742
      */
     public function testGetHelperWorksWithPredefinedClassNames()
     {
@@ -933,8 +960,8 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         } catch (Exception $e) {
             $this->assertContains('only takes strings', $e->getMessage());
         }
-        
-        
+
+
         try {
             $helper = $view->getHelper('Datetime');
         } catch (Exception $e) {
@@ -947,7 +974,7 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $this->view = new Zend_View();
         $this->assertFalse($this->view->useStreamWrapper());
     }
-    
+
     public function testUseStreamWrapperStateShouldBeConfigurable()
     {
         $this->testUseStreamWrapperFlagShouldDefaultToFalse();
@@ -956,13 +983,184 @@ class Zend_ViewTest extends PHPUnit_Framework_TestCase
         $this->view->setUseStreamWrapper(false);
         $this->assertFalse($this->view->useStreamWrapper());
     }
+
+    /**
+     * @group ZF-5748
+     */
+    public function testRenderShouldNotAllowScriptPathsContainingParentDirectoryTraversal()
+    {
+        $view = new Zend_View();
+        try {
+            $view->render('../foobar.html');
+            $this->fail('Should not allow parent directory traversal');
+        } catch (Zend_View_Exception $e) {
+            $this->assertContains('parent directory traversal', $e->getMessage());
+        }
+
+        try {
+            $view->render('foo/../foobar.html');
+            $this->fail('Should not allow parent directory traversal');
+        } catch (Zend_View_Exception $e) {
+            $this->assertContains('parent directory traversal', $e->getMessage());
+        }
+
+        try {
+            $view->render('foo/..\foobar.html');
+            $this->fail('Should not allow parent directory traversal');
+        } catch (Zend_View_Exception $e) {
+            $this->assertContains('parent directory traversal', $e->getMessage());
+        }
+    }
+
+    /**
+     * @group ZF-5748
+     */
+    public function testLfiProtectionFlagShouldBeEnabledByDefault()
+    {
+        $view = new Zend_View();
+        $this->assertTrue($view->isLfiProtectionOn());
+    }
+
+    /**
+     * @group ZF-5748
+     */
+    public function testLfiProtectionFlagMayBeDisabledViaConstructorOption()
+    {
+        $view = new Zend_View(array('lfiProtectionOn' => false));
+        $this->assertFalse($view->isLfiProtectionOn());
+    }
+
+    /**
+     * @group ZF-5748
+     */
+    public function testLfiProtectionFlagMayBeDisabledViaMethodCall()
+    {
+        $view = new Zend_View();
+        $view->setLfiProtection(false);
+        $this->assertFalse($view->isLfiProtectionOn());
+    }
+
+    /**
+     * @group ZF-5748
+     */
+    public function testDisablingLfiProtectionAllowsParentDirectoryTraversal()
+    {
+        $view = new Zend_View(array(
+            'lfiProtectionOn' => false,
+            'scriptPath'      => dirname(__FILE__) . '/View/_templates/',
+        ));
+        try {
+            $test = $view->render('../_stubs/scripts/LfiProtectionCheck.phtml');
+            $this->assertContains('LFI', $test);
+        } catch (Zend_View_Exception $e) {
+            $this->fail('LFI attack failed: ' . $e->getMessage());
+        }
+    }
+
+    /**
+     * @group ZF-6087
+     */
+    public function testConstructorShouldAllowPassingArrayOfHelperPaths()
+    {
+        $view = new Zend_View(array(
+            'helperPath' => array(
+                'My_View'   => 'My/View/',
+            ),
+        ));
+        $paths = $view->getHelperPaths();
+        $this->assertTrue(array_key_exists('My_View_', $paths), var_export($paths, 1));
+    }
+
+    /**
+     * @group ZF-6087
+     */
+    public function testConstructorShouldAllowPassingArrayOfFilterPaths()
+    {
+        $view = new Zend_View(array(
+            'filterPath' => array(
+                'My_View'   => 'My/View/',
+            ),
+        ));
+        $paths = $view->getFilterPaths();
+        $this->assertTrue(array_key_exists('My_View_', $paths), var_export($paths, 1));
+    }
+
+    /**
+     * @group ZF-8177
+     */
+    public function testRegisterHelperShouldRegisterHelperWithView()
+    {
+    	require_once dirname(__FILE__) . '/View/_stubs/HelperDir1/Stub1.php';
+
+    	$view = new Zend_View();
+    	$helper = new Foo_View_Helper_Stub1();
+    	$view->registerHelper($helper, 'stub1');
+
+    	$this->assertEquals($view->getHelper('stub1'), $helper);
+    	$this->assertEquals($view->stub1(), 'foo');
+    }
+
+    /**
+     * @group ZF-8177
+     * @expectedException Zend_View_Exception
+     */
+    public function testRegisterHelperShouldThrowExceptionIfNotProvidedAnObject()
+    {
+        $view = new Zend_View();
+        $view->registerHelper('Foo', 'foo');
+    }
+
+    /**
+     * @group ZF-8177
+     * @expectedException Zend_View_Exception
+     */
+    public function testRegisterHelperShouldThrowExceptionIfProvidedANonHelperObject()
+    {
+        $view   = new Zend_View();
+        $helper = new stdClass;
+        $view->registerHelper($helper, 'foo');
+    }
+
+    /**
+     * @group ZF-8177
+     */
+    public function testRegisterHelperShouldRegisterViewObjectWithHelper()
+    {
+    	require_once 'Zend/View/Helper/Doctype.php';
+    	$view = new Zend_View();
+    	$helper = new Zend_View_Helper_Doctype();
+    	$view->registerHelper($helper, 'doctype');
+        $this->assertSame($view, $helper->view);
+    }
+
+    /**
+     * @group ZF-9000
+	 * @group ZF-4622
+     */
+    public function testAddingStreamSchemeAsScriptPathShouldNotMangleThePath()
+    {
+    	$view = new Zend_View();
+        $path = rtrim('file://' . str_replace('\\', '/', realpath(dirname(__FILE__))), '/') . '/';
+        $view->addScriptPath($path);
+        $paths = $view->getScriptPaths();
+        $this->assertContains($path, $paths, var_export($paths, 1));
+    }
+    
+    /**
+     * @group ZF-10042
+     */
+    public function testConstructViewObjectWithInitialVariables()
+    {
+        $view = new Zend_View(array('assign' => array('foo' => 'bar')));
+        $this->assertEquals('bar', $view->foo);
+    }
 }
 
 /**
  * @category   Zend
  * @package    Zend_View
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_ViewTest_Extension extends Zend_View
